==> haskell-hspec-discover-2.5.5-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-discover.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-discover
version: 2.5.5
id: hspec-discover-2.5.5-CfE6M9NqwI790sUg8X3T3c
key: hspec-discover-2.5.5-CfE6M9NqwI790sUg8X3T3c
license: MIT
copyright: (c) 2012-2018 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
author: Simon Hengel <sol@typeful.net>
stability: experimental
homepage: http://hspec.github.io/
synopsis: Automatically discover and run Hspec tests
description:
    Automatically discover and run Hspec tests
    .
    <http://hspec.github.io/hspec-discover.html>
category: Testing
abi: b75956a74bd9e4d96a89b94b3257899c
exposed-modules:
    Test.Hspec.Discover.Config Test.Hspec.Discover.Run
    Test.Hspec.Discover.Sort
hidden-modules: Paths_hspec_discover
import-dirs: /usr/lib/ghc-8.4.3/site-local/hspec-discover-2.5.5
library-dirs: /usr/lib/ghc-8.4.3/site-local/hspec-discover-2.5.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/hspec-discover-2.5.5
hs-libraries: HShspec-discover-2.5.5-CfE6M9NqwI790sUg8X3T3c
depends:
    base-4.11.1.0 directory-1.3.1.5 filepath-1.4.2
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
haddock-interfaces: /usr/share/doc/haskell-hspec-discover/html/hspec-discover.haddock
haddock-html: /usr/share/doc/haskell-hspec-discover/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-discover-2.5.5-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-discover.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-discover
version: 2.5.5
id: hspec-discover-2.5.5-ANYlVdOrloTFokPu0upSEJ
key: hspec-discover-2.5.5-ANYlVdOrloTFokPu0upSEJ
license: MIT
copyright: (c) 2012-2018 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
author: Simon Hengel <sol@typeful.net>
stability: experimental
homepage: http://hspec.github.io/
synopsis: Automatically discover and run Hspec tests
description:
    Automatically discover and run Hspec tests
    .
    <http://hspec.github.io/hspec-discover.html>
category: Testing
abi: a0939422140f776d6a554ea7bf140410
exposed-modules:
    Test.Hspec.Discover.Config Test.Hspec.Discover.Run
    Test.Hspec.Discover.Sort
hidden-modules: Paths_hspec_discover
import-dirs: /usr/lib/ghc-8.4.3/site-local/hspec-discover-2.5.5
library-dirs: /usr/lib/ghc-8.4.3/site-local/hspec-discover-2.5.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/hspec-discover-2.5.5
hs-libraries: HShspec-discover-2.5.5-ANYlVdOrloTFokPu0upSEJ
depends:
    base-4.11.1.0 directory-1.3.1.5 filepath-1.4.2
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
haddock-interfaces: /usr/share/doc/haskell-hspec-discover/html/hspec-discover.haddock
haddock-html: /usr/share/doc/haskell-hspec-discover/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
